@@ -1,8 +1,9 @@
 from testcomponent import *
 from testinputadapter import *
-from testgraphers import *
 from testdecoding import *
-from testtranscoding import *
+from testgraphing import *
+from testanalyzing import *
+from testencoding import *
 from unit_timeside import *
 
 unittest.main(testRunner=TestRunner())
