@@ -22,16 +22,9 @@
 
 from timeside.core import Processor, implements, interfacedoc
 from timeside.api import IEncoder
-from numpy import array, frombuffer, getbuffer, float32
+from timeside.encoder.gstutils import *
 
-import pygst
-pygst.require('0.10')
-import gst
-import gobject
-gobject.threads_init()
-
-
-class WavEncoder(Processor):
+class WavEncoder(GstEncoder):
     """ gstreamer-based encoder """
     implements(IEncoder)
 
@@ -67,21 +60,8 @@ class WavEncoder(Processor):
         else:
             self.pipe += '! appsink name=app sync=False'
             
-        self.pipeline = gst.parse_launch(self.pipe)
-        # store a pointer to appsrc in our encoder object
-        self.src = self.pipeline.get_by_name('src')
-        # store a pointer to appsink in our encoder object
-        self.app = self.pipeline.get_by_name('app')
-        
-        srccaps = gst.Caps("""audio/x-raw-float,
-            endianness=(int)1234,
-            channels=(int)%s,
-            width=(int)32,
-            rate=(int)%d""" % (int(channels), int(samplerate)))
-        self.src.set_property("caps", srccaps)
-
         # start pipeline
-        self.pipeline.set_state(gst.STATE_PLAYING)
+        self.start_pipeline(channels, samplerate)
         
     @staticmethod
     @interfacedoc
@@ -112,17 +92,3 @@ class WavEncoder(Processor):
     def set_metadata(self, metadata):
         #TODO
         pass
-
-    @interfacedoc
-    def process(self, frames, eod=False):
-        self.eod = eod
-        buf = self.numpy_array_to_gst_buffer(frames)
-        self.src.emit('push-buffer', buf)
-        if self.streaming:
-            self.chunk = self.app.emit('pull-buffer')
-        return frames, eod
-        
-    def numpy_array_to_gst_buffer(self, frames):
-        """ gstreamer buffer to numpy array conversion """
-        buf = gst.Buffer(getbuffer(frames))
-        return buf
